function c=comp_dgtreal(f,g,a,M,lt,phasetype)
%-*- texinfo -*-
%@deftypefn {Function} comp_dgtreal
%@verbatim
%COMP_DGTREAL  Compute a DGTREAL
%   Usage:  c=comp_dgtreal(f,g,a,M,lt,phasetype);
%
%   Input parameters:
%         f     : Input data
%         g     : Window function.
%         a     : Length of time shift.
%         M     : Number of modulations.
%         L     : Length of transform to do.
%   Output parameters:
%         c     : M/2+1*N array of coefficients.
%
%@end verbatim
%@strong{Url}: @url{http://ltfat.github.io/doc/comp/comp_dgtreal.html}
%@end deftypefn

% Copyright (C) 2005-2023 Peter L. Soendergaard <peter@sonderport.dk> and others.
% This file is part of LTFAT version 2.6.0
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.

%   AUTHOR : Peter L. Soendergaard.

if lt(2)==1
    c = comp_sepdgtreal(f,g,a,M,phasetype);
else
    % Quinqunx lattice
    c = comp_nonsepdgtreal_quinqux(f,g,a,M);            
end;






